# remirepo/fedora spec file for php-tecnickcom-tc-lib-pdf-font
#
# SPDX-FileCopyrightText:  Copyright 2023-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%global gh_commit    55e56421150d15930f81c6469d08819a53ef96c1
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global c_vendor     tecnickcom
%global gh_owner     tecnickcom
%global gh_project   tc-lib-pdf-font
%global php_project  %{_datadir}/php/Com/Tecnick/Pdf/Font
%global with_tests   0%{!?_without_tests:1}
%global font_version 2.1.0

Name:           php-%{gh_owner}-%{gh_project}
Version:        2.6.7
Release:        1%{?dist}
Summary:        PHP library containing PDF page formats and definitions

License:        LGPL-3.0-or-later
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{name}-%{version}-%{?gh_short}.tar.gz
Source1:        https://github.com/tecnickcom/tc-font-mirror/archive/refs/tags/%{font_version}.tar.gz

# Fix path
Patch0:         %{name}-rpm.patch

BuildArch:      noarch
%if %{with_tests}
# For tests
%global phpunit %{_bindir}/phpunit10
BuildRequires:  phpunit10 >= 10.5.40
BuildRequires:  php(language) >= 8.1
BuildRequires:  php-json
BuildRequires:  php-pcre
BuildRequires:  php-spl
BuildRequires:  php-zlib
BuildRequires: (php-composer(%{c_vendor}/tc-lib-file)         >= 2.1.4   with php-composer(%{c_vendor}/tc-lib-file)         < 3)
BuildRequires: (php-composer(%{c_vendor}/tc-lib-unicode-data) >= 2.0     with php-composer(%{c_vendor}/tc-lib-unicode-data) < 3)
BuildRequires: (php-composer(%{c_vendor}/tc-lib-pdf-encrypt)  >= 2.1     with php-composer(%{c_vendor}/tc-lib-pdf-encrypt)  < 3)
%endif
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#    "php": ">=8.1",
#    "ext-json": "*",
#    "ext-pcre": "*",
#    "ext-zlib": "*",
#    "tecnickcom/tc-lib-file": "^2.1",
#    "tecnickcom/tc-lib-unicode-data": "^2.0",
#    "tecnickcom/tc-lib-pdf-encrypt": "^2.1"
Requires:       php(language) >= 8.1
Requires:       php-json
Requires:       php-pcre
Requires:       php-spl
Requires:       php-zlib
Requires:      (php-composer(%{c_vendor}/tc-lib-file)         >= 2.1.4   with php-composer(%{c_vendor}/tc-lib-file)         < 3)
Requires:      (php-composer(%{c_vendor}/tc-lib-unicode-data) >= 2.0     with php-composer(%{c_vendor}/tc-lib-unicode-data) < 3)
Requires:      (php-composer(%{c_vendor}/tc-lib-pdf-encrypt)  >= 2.1     with php-composer(%{c_vendor}/tc-lib-pdf-encrypt)  < 3)
# From phpcompatinfo report for version 2.0.8
# none
Requires:       php-composer(fedora/autoloader)

# Composer
Provides:       php-composer(%{c_vendor}/%{gh_project}) = %{version}
# Upstream package name
Provides:       php-%{gh_project} = %{version}


%description
PHP library containing PDF page formats and definitions.

The initial source code has been extracted from TCPDF (http://www.tcpdf.org).


%prep
%setup -q -n %{gh_project}-%{gh_commit} -a 1
%patch -P0 -p0 -b .rpm

: Sanity check
grep -q '^%{version}$' VERSION
grep -q 'tc-font-mirror/archive/refs/tags/%{font_version}' util/composer.json


%build
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{_datadir}/php/Com/Tecnick/File/autoload.php',
    '%{_datadir}/php/Com/Tecnick/Unicode/Data/autoload.php',
    '%{_datadir}/php/Com/Tecnick/Pdf/Encrypt/autoload.php',
]);
EOF


%install
mkdir -p   $(dirname %{buildroot}%{php_project})
cp -pr src %{buildroot}%{php_project}

cd util
mkdir -p %{buildroot}/%{_datadir}/%{name}
php bulk_convert.php --outpath=%{buildroot}%{_datadir}/%{name}/

install -Dpm 755 convert.php %{buildroot}%{_bindir}/%{name}-convert


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require '%{buildroot}%{php_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Test\\', dirname(__DIR__) . '/test');
EOF

sed -e 's:/util/vendor/tecnickcom/tc-font-mirror/:/tc-font-mirror-2.1.0/:' -i test/*php

ret=0
for cmdarg in php php81 php82 php83 php84; do
   if which $cmdarg; then
      set $cmdarg
      cp phpunit.xml.dist phpunit.xml
      $1 ${2:-%{phpunit}} --migrate-configuration || :
      $1 -d memory_limit=1G ${2:-%{phpunit}} --no-coverage || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%license LICENSE
%doc composer.json
%doc *.md
%{php_project}
%{_datadir}/%{name}
%{_bindir}/%{name}-convert


%changelog
* Mon Apr 28 2025 Remi Collet <remi@remirepo.net> - 2.6.7-1
- update to 2.6.7
- raise dependency on tecnickcom/tc-lib-file 2.1.4
  see https://github.com/tecnickcom/tc-lib-pdf-font/pull/10

* Fri Feb  7 2025 Remi Collet <remi@remirepo.net> - 2.6.6-1
- update to 2.6.6

* Fri Dec 27 2024 Remi Collet <remi@remirepo.net> - 2.6.5-1
- update to 2.6.5
- raise dependency on PHP 8.1

* Mon Dec 23 2024 Remi Collet <remi@remirepo.net> - 2.6.4-1
- update to 2.6.4
- raise dependency on tecnickcom/tc-lib-file 2.1
- re-license spec file to CECILL-2.1

* Mon Nov 25 2024 Remi Collet <remi@remirepo.net> - 2.6.2-1
- update to 2.6.2 (no change)

* Mon Oct 28 2024 Remi Collet <remi@remirepo.net> - 2.6.1-1
- update to 2.6.1

* Mon Sep 16 2024 Remi Collet <remi@remirepo.net> - 2.6.0-1
- update to 2.6.0

* Mon Sep  9 2024 Remi Collet <remi@remirepo.net> - 2.5.1-1
- update to 2.5.1 (no change)

* Mon Aug 26 2024 Remi Collet <remi@remirepo.net> - 2.5.0-1
- update to 2.5.0
- raise dependency on PHP 8.0

* Mon Aug 19 2024 Remi Collet <remi@remirepo.net> - 2.4.2-1
- update to 2.4.2

* Fri Apr 12 2024 Remi Collet <remi@remirepo.net> - 2.2.3-1
- update to 2.2.3

* Tue Mar 26 2024 Remi Collet <remi@remirepo.net> - 2.2.2-1
- update to 2.2.2

* Fri Mar 22 2024 Remi Collet <remi@remirepo.net> - 2.2.0-1
- update to 2.2.0

* Mon Jan 29 2024 Remi Collet <remi@remirepo.net> - 2.1.1-1
- update to 2.1.1

* Wed Nov 29 2023 Remi Collet <remi@remirepo.net> - 2.0.13-1
- update to 2.0.13

* Tue Nov 28 2023 Remi Collet <remi@remirepo.net> - 2.0.11-1
- initial package, version 2.0.11

